<?php

function importer_form($form_state)
{
  global $base_path, $processing; //, $cml_enabled;

  $modules = importer_plugins('importer');
  $settings = variable_get('importer_settings', '');

  // Загружаем данные для обработки
  if (isset($modules) && count($modules)) {
    foreach ($modules as $name => $module) {

      $form[$name] = array(
        '#type' => 'fieldset',
        '#title' => $module['name'],
        '#description' => $module['desription'],
        '#collapsible' => TRUE,
        '#collapsed' => FALSE,
        '#weight' => (isset($module['weight']) ? $module['weight'] : 0),
      );

      // Подгружаем команды плагинов
      if (isset($module['commands'])) {
        foreach ($module['commands'] as $plugin_name => $plugin) {
          $options = array();
          $options_set = array();
          $commands = isset($settings[$name])? $settings[$name]['commands']: array();

          /*if (isset($plugin['options']) && is_array($plugin['options'])){
            foreach ($plugin['options'] as $option => $description){
              $options[$option] = $description;
            }
          } else {
            $options[$plugin_name] = isset($plugin['options']) ? $plugin['options'] : array();
          }*/

          //  Установка сохраненых значений
          if (isset($plugin['options']) && is_array($plugin['options'])){
            foreach ($plugin['options'] as $option => $description){
              $options[$option] = $description;
              if(isset($commands[$plugin_name]['options'][$option]) && $commands[$plugin_name]['options'][$option]){
                $options_set[$option] = $option;
              }
            }
          }

          $form[$name][$name . '__' . $plugin_name] = array(
            '#type' => 'checkboxes',
            '#title' => isset($plugin['title']) ? $plugin['title'] : '',
            '#description' => isset($plugin['desription']) ? $plugin['desription'] : '',
            '#default_value' => $options_set,
            '#options' => $options,
          );
        }
      }

      // Получаем список файлов для обработки
      if (isset($module['data_file'])) {
        $default = array();
        foreach ($module['data_file'] as $n => $file)
          $default[$n] = $n;
        $form[$name][$name . '_file'] = array(
          '#type' => 'select',
          '#title' => t('Select file for import'),
          '#description' => t('Select file for import.'),
          '#default_value' => $default,
          '#options' => $module['data_file'],
          '#multiple' => true,
          '#size' => min(9, count($module['data_file'])),
        );
      }

      if (isset($module['data_file_format'])) {
        $form[$name][$name . '_file_format'] = array(
          '#type' => 'hidden',
          '#value' => $module['data_file_format'],
        );
      }

    }

    $form['save'] = array(
      '#type' => 'submit',
      '#value' => t('Save'),
      '#weight' => 999,
    );

    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Submit'),
      '#weight' => 1000,
    );

  } else
    $form['event'] = array(
      '#type' => 'item',
      '#title' => t('There are no plugins.'),
    );

  return $form;
}

function importer_form_submit($form, &$form_state)
{
  $data = array();
  $modules = importer_plugins('importer');

  // Modules
  foreach ($modules as $name => $module) {
    if (isset($form_state['values'][$name . '_file'])) {

      // Data files
      foreach ($form_state['values'][$name . '_file'] as $select) {
        $data[$name]['file_format'] = $form_state['values'][$name . '_file_format'];
        $data[$name]['files'][] = $module['data_file'][$select];
        $data[$name]['commands'] = $module['commands'];
      }

      // Commands
      foreach ($data[$name]['commands'] as $command => &$value)

        // Options
        foreach ($value['options'] as $option => $description)
          $value['options'][$option] = (bool)$form_state['values'][$name . '__' . $command][$option];

    }
  }

  if (isset($form_state['values']['op']) && $form_state['values']['op'] == t('Save')) {
    drupal_set_message(t('Imorter settings save successful'), 'status');
    variable_set('importer_settings', $data);
  } else {
    importer_run($data);
  }
}

function importer_page()
{
  $output = drupal_get_form('importer_form');
  return $output;
}

//
//
//

function importer_settings()
{
  return drupal_get_form('importer_settings_form');
}

function importer_settings_form(&$form_state = array())
{
  global $user;

  $form['Defaults'] = array(
    '#type' => 'fieldset',
    '#title' => t('Default settings'),
    '#description' => t('Default settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['Defaults']['importer_data_path'] = array(
    '#type' => 'textfield',
    '#size' => 50,
    '#title' => t('Full path to exchange folder'),
    '#description' => t('Path must be without /import_files'),
    '#default_value' => isset($form_state['post']['importer_data_path']) ?
      $form_state['post']['importer_data_path'] :
      variable_get('importer_data_path', drupal_get_path('module', 'importer') . '/data'),
  );

  // Get a list of formats that the current user has access to.
  $formats = filter_formats();
  foreach ($formats as $format)
    $options[$format->format] = $format->name;

  $form['Defaults']['cml_product_format'] = array(
    '#type' => 'select',
    '#title' => t('Text format'),
    '#options' => $options,
    '#default_value' => isset($form_state['post']['cml_product_format']) ?
      $form_state['post']['cml_product_format'] :
      variable_get('cml_product_format', 1),
    '#weight' => 10,
    '#description' => t('The body format of product'),
  );

  $form['Defaults']['importer_image_settings'] = array(
    '#type' => 'select',
    '#title' => t('Image settings'),
    '#description' => t('Image settings'),
    '#default_value' => isset($form_state['post']['importer_image_settings']) ?
      $form_state['post']['importer_image_settings'] :
      variable_get('importer_image_settings', 1),
    '#options' => array('Move', 'Copy'),
  );

  $importer_forms = importer_plugins('importer_settings', $form, $form_state);

  $form = array_merge($form, $importer_forms);

  $form['Defaults']['Bindings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Bindings settings'),
    '#description' => t('The bindings configuration settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  return system_settings_form($form);
}